=======
Credits
=======

Development Lead
----------------

* Fernando Macedo <fgmacedo@gmail.com>

Contributors
------------

* Guilherme Nepomuceno <piercio@loggi.com>
* Rafael Rêgo <crafards@gmail.com>
* Raphael Schrader <raphael@schradercloud.de>


Scaffolding
-----------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
